## 0.20.0 (2025-07-13)

### Feat

- show library name instead of __main__.py during module execution
- show library name instead of __main__.py during module execution

### Fix

- program_name base path and supported python versions
- program_name base path and supported python versions
